==> synfigstudio_1.2.1.orig.tar.gz: synfigstudio-1.2.1/src/languages.inc.c <==
//
// this file should be modified by bash-script
// please keep following syntax:
//
// // full-line comment
// { "code", "Language name" }, // optional end-line comment
// { "code", "Language name" },
//
// please don't use backslash () char in quotes
//
//

{ "ar",          "Arabick",                          },
{ "bs",          "Bosnian",                          },
{ "ca",          "Catalan",                          },
{ "ca@valencia", "Catalan (Valencian)",              },
{ "cs",          "Czech",                            },
{ "cs_CZ",       "Czech (Czechia)",                  },
{ "da",          "Danish",                           },
{ "de",          "German",                           },
{ "el_GR",       "Greek (Greece)",                   },
{ "en",          "English - default of development", },
{ "en_CZ",       "English (Czechia)",                },
{ "en_GB",       "English (United Kingdom)",         },
{ "es",          "Spanish",                          },
{ "es_PY",       "Spanish (Paraguay)",               },
{ "eu",          "Basque",                           },
{ "eu_ES",       "Basque (Spain)",                   },
{ "fa_IR",       "Farsi (Iran)",                     },
{ "fr",          "French",                           },
{ "gl",          "Galician",                         },
{ "he",          "Hebrew",                           },
{ "hi_IN",       "Hindi (India)",                    },
{ "hu",          "Hungarian",                        },
{ "it",          "Italian",                          },
{ "ja",          "Japanese",                         },
{ "ja_JP",       "Japanese (Japan)",                 },
{ "lt",          "Lithuanian",                       },
{ "lv",          "Latvian",                          },
{ "nl",          "Dutch",                            },
{ "no_NO",       "Norwegian (Norway)",               },
{ "pl_PL",       "Polish (Poland)",                  },
{ "pt",          "Portuguese",                       },
{ "pt_BR",       "Portuguese (Brazil)",              },
{ "ro",          "Romanian",                         },
{ "ru",          "Russian",                          },
{ "si",          "Sinhala",                          },
{ "sk",          "Slovak",                           },
{ "sk_SK",       "Slovak (Slovakia)",                },
{ "sl",          "Slovene",                          },
{ "sr_RS",       "Serbian (Serbia)",                 },
{ "sv_SE",       "Swedish (Sweden)",                 },
{ "tr",          "Turkish",                          },
{ "ur",          "Urdu",                             },
{ "uz@Latn",     "Urdu (Latn)",                      },
{ "zh_CN",       "Chinese (China)",                  },
{ "zh-Hant",     "Chinese Traditional",              },
{ "zh_TW",       "Chinese (Taiwan)",                 },
{ "zh_TW.Big5",  "Chinese (Taiwan) big5",            },

==> synfigstudio-1.4.0.tar.gz: synfigstudio-1.4.0/src/languages.inc.c <==
//
// this file should be modified by bash-script
// please keep following syntax:
//
// // full-line comment
// { "code", "Language name" }, // optional end-line comment
// { "code", "Language name" },
//
// please don't use backslash () char in quotes
//
//

{ "aa_DJ",       "Afar",                             },
{ "ar",          "Arabick",                          },
{ "bs",          "Bosnian",                          },
{ "ca",          "Catalan",                          },
{ "ca@valencia", "Catalan (Valencian)",              },
{ "cs",          "Czech",                            },
{ "cs_CZ",       "Czech (Czechia)",                  },
{ "da",          "Danish",                           },
{ "de",          "German",                           },
{ "el_GR",       "Greek (Greece)",                   },
{ "en",          "English - default of development", },
{ "en_CZ",       "English (Czechia)",                },
{ "en_GB",       "English (United Kingdom)",         },
{ "es",          "Spanish",                          },
{ "es_AR",       "Spanish (Argentina)",              },
{ "es_PY",       "Spanish (Paraguay)",               },
{ "eu",          "Basque",                           },
{ "eu_ES",       "Basque (Spain)",                   },
{ "fa_IR",       "Farsi (Iran)",                     },
{ "fr",          "French",                           },
{ "gl",          "Galician",                         },
{ "he",          "Hebrew",                           },
{ "hi_IN",       "Hindi (India)",                    },
{ "hu",          "Hungarian",                        },
{ "it",          "Italian",                          },
{ "ja",          "Japanese",                         },
{ "ja_JP",       "Japanese (Japan)",                 },
{ "kab",         "Kabyle",                           },
{ "lt",          "Lithuanian",                       },
{ "lv",          "Latvian",                          },
{ "nb",          "Norwegian",                        },
{ "ne",          "Nepali",                           },
{ "nl",          "Dutch",                            },
{ "pl_PL",       "Polish (Poland)",                  },
{ "pt",          "Portuguese",                       },
{ "pt_BR",       "Portuguese (Brazil)",              },
{ "ro",          "Romanian",                         },
{ "ru",          "Russian",                          },
{ "si",          "Sinhala",                          },
{ "sk",          "Slovak",                           },
{ "sk_SK",       "Slovak (Slovakia)",                },
{ "sl",          "Slovene",                          },
{ "sr_RS",       "Serbian (Serbia)",                 },
{ "sv_SE",       "Swedish (Sweden)",                 },
{ "tr",          "Turkish",                          },
{ "uk",          "Ukrainian",                        },
{ "ur",          "Urdu",                             },
{ "uz@Latn",     "Urdu (Latn)",                      },
{ "zh_CN",       "Chinese (China)",                  },
{ "zh-Hant",     "Chinese Traditional",              },
{ "zh_TW",       "Chinese (Taiwan)",                 },
{ "zh_TW.Big5",  "Chinese (Taiwan) big5",            },
